View source: R/visualise_single_sequence.R
| convert_input_seq_to_sequence_list | R Documentation |
visualise_single_sequence() helper)Takes a single input sequence and an integer line length, and splits the input
sequence into lines of that length (with the last line potentially being shorter).
Optionally inserts empty strings "" after each line to space them out.
convert_input_seq_to_sequence_list(
input_seq,
line_length,
spacing = 1,
start_spaces = FALSE,
end_spaces = FALSE
)
input_seq |
|
line_length |
|
spacing |
|
start_spaces |
|
end_spaces |
|
character vector. The input sequence split into multiple lines, with specified spacing in between.
convert_input_seq_to_sequence_list(
"GGCGGCGGC",
line_length = 6,
spacing = 1,
start_spaces = TRUE,
end_spaces = TRUE
)
convert_input_seq_to_sequence_list(
"GGCGGCGGC",
line_length = 3,
spacing = 2
)
convert_input_seq_to_sequence_list(
"GGCGGCGGC",
line_length = 3,
spacing = 2,
end_spaces = TRUE
)
convert_input_seq_to_sequence_list(
"GGCGGCGGC",
line_length = 6,
spacing = 0,
start_spaces = TRUE,
end_spaces = FALSE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.