View source: R/visualise_single_sequence.R
| convert_sequences_to_annotations | R Documentation |
visualise_single_sequence() helper)Takes the sequence list output from convert_input_seq_to_sequence_list() and creates a dataframe
specifying x and y coordinates and the character to plot at each coordinate. This applies to both
the sequence itself (e.g. determining where on the plot to place an "A") and the periodicit
annotations of index number (e.g. determining where on the plot to annotate base number 15).
convert_sequences_to_annotations(
sequences,
line_length,
interval = 15,
annotations_above = TRUE,
annotation_vertical_position = 1/3
)
sequences |
|
line_length |
|
interval |
|
annotations_above |
|
annotation_vertical_position |
|
dataframe Dataframe of coordinates and labels (e.g. "A" or "15), readable by geom_text.
convert_sequences_to_annotations(
c("GGCGGC", "", "ATCG", ""),
line_length = 6,
interval = 3,
annotations_above = TRUE,
annotation_vertical_position = 1/3
)
convert_sequences_to_annotations(
c("GGCGGC", "", "ATCG", ""),
line_length = 6,
interval = 0
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.