| create_image_data | R Documentation |
ggDNAvis helper)Takes a character vector of sequences (which are allowed to be empty "" to
act as a spacing line) and rasterises it into a dataframe that ggplot can read.
create_image_data(sequences)
sequences |
|
dataframe. Rasterised dataframe representation of the sequences, readable by ggplot2::ggplot().
create_image_data(c("ATCG", "", "GGCGGC", ""))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.