| debug_join_vector_str | R Documentation |
ggDNAvis debug helper)Takes a character/string vector, and prints it to the console separated by ", ".
This allows the output to be copy-pasted into a vector within an R script.
Used for taking vector outputs and then writing them as literals within a script.
E.g. when given input strsplit("ABCD", split = "")[[1]], prints "A", "B", "C", "D",
which can be directly copy-pasted within c() to input that vector.
Printing normally via print(strsplit("ABCD", split = "")[[1]]) instead prints
[1] "A" "B" "C" "D", which is not valid vector input so can't be copy-pasted directly.
See debug_join_vector_num() for the equivalent for numeric vectors.
debug_join_vector_str(vector)
vector |
|
None (invisible NULL) - uses cat() to output directly to console.
debug_join_vector_str(c("A", "B", "C", "D"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.