- low_colour
character. The colour that should be used to represent minimum probability of methylation/modification (defaults to blue).
- high_colour
character. The colour that should be used to represent maximum probability of methylation/modification (defaults to red).
- low_clamp
numeric. The minimum probability below which all values are coloured low_colour. Defaults to 0 (i.e. no clamping).
- high_clamp
numeric. The maximum probability above which all values are coloured high_colour. Defaults to 255 (i.e. no clamping, assuming Nanopore > SAM style modification calling where probabilities are 8-bit integers from 0 to 255).
- full_range
numeric vector, length 2. The total range of possible probabilities. Defaults to c(0, 255), which is appropriate for Nanopore > SAM style modification calling where probabilities are 8-bit integers from 0 to 255.
May need to be set to c(0, 1) if probabilites are instead stored as decimals. Setting any other value is advanced use and should be done for a good reason.
- precision
integer. How many different shades should be rendered. Larger values give a smoother gradient. Defaults to 10^3 i.e. 1000, which looks smooth to my eyes and isn't too intensive to calculate.
- background_colour
character. The colour the background should be drawn (defaults to white).
- x_axis_title
character. The desired x-axis title. Defaults to NULL.
- do_x_ticks
logical. Boolean specifying whether x axis ticks should be enabled (TRUE, default) or disabled (FALSE).
- do_side_scale
logical. Boolean specifying whether a smaller scalebar should be rendered on the right. Defaults to FALSE.
I think it is unlikely anyone would want to use this, but the option is here. One potential usecase is that this scalebar shows the raw probability values (e.g. 0 to 255), whereas the x-axis is normalised to 0-1.
- side_scale_title
character. The desired title for the right-hand scalebar, if turned on. Defaults to NULL.
- outline_colour
character. The colour of the scalebar outline. Defaults to black.
- outline_linewidth
numeric. The linewidth of the scalebar outline. Defaults to 1. Set to 0 to disable scalebar outline.